@@ -1,4 +1,5 @@
 from pydi.utils import Resolve
+from pydi.exceptions import InitializationFailed
 
 
 class Component(object):
@@ -30,7 +31,12 @@ class Component(object):
         args = map(lambda x: x(**x.kwargs), self.dependencies)
 
         target = self.cls
-        obj = target(*args, **kwargs) if callable(target) else target
+        try:
+            obj = target(*args, **kwargs) if callable(target) else target
+        except TypeError:
+            raise InitializationFailed(target=target,
+                                       target_args=args,
+                                       target_kwargs=kwargs)
 
         if self._shared:
             self._instance = obj
